<?php

/**
 * @file
 * Views integration for Webform Events module.
 */

/**
 * Implementation of hook_views_data().
 */
function webform_events_views_data() {
  $data = array();
  $data['webform_events']['table']['group'] = t('Webform events');
  $data['webform_events']['table']['base'] = array(
    'field' => 'nid',
    'title' => t('Webform events'),
    'help' => t("Webform events contains event-related content."),
    'weight' => -10,
  );
  $data['webform_events']['table']['join'] = array(
    'node' => array(
      'left_field' => 'nid',
      'field' => 'nid',
    ),
  );
  $data['webform_events']['nid'] = array(
    'title' => t('Webform events'),
    'help' => t("Webform events related information."),
    'relationship' => array(
      'base' => 'node',
      'field' => 'nid',
      'handler' => 'views_handler_relationship',
      'label' => t('Webform event'),
    ),
  );
  $data['webform_events']['attendance_limit'] = array(
    'title' => t('Attendance limit'),
    'help' => t('A limit on the number of attendees to a webform event.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => FALSE,
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['webform_events']['slots_taken'] = array(
    'title' => t('Attendance slots taken'),
    'help' => t('The number of registration slots that has been taken.'),
    'field' => array(
      'handler' => 'views_webform_events_handler_field_slots_taken',
      'notafield' => TRUE,
    ),
  );
  $data['webform_events']['slots_available'] = array(
    'title' => t('Attendance slots remaining'),
    'help' => t('The number of registration slots available until attendance limit is reached.'),
    'field' => array(
      'handler' => 'views_webform_events_handler_field_slots_available',
      'notafield' => TRUE,
    ),
  );
  $data['webform_events']['registration_status'] = array(
    'title' => t('Registration status'),
    'help' => t('The status of registration (open or closed).'),
    'field' => array(
      'handler' => 'views_webform_events_handler_field_registration_status',
      'notafield' => TRUE,
    ),
  );
  return $data;
}

/**
 * Implementation of hook_views_handlers().
 */
function webform_events_views_handlers() {
  return array(
    'info' => array(
      'path' => drupal_get_path('module', 'webform_events') . '/includes',
    ),
    'handlers' => array(
      'views_webform_events_handler_field_slots_taken' => array(
        'parent' => 'views_handler_field',
      ),
      'views_webform_events_handler_field_slots_available' => array(
        'parent' => 'views_handler_field',
      ),
      'views_webform_events_handler_field_registration_status' => array(
        'parent' => 'views_handler_field',
      ),
    ),
  );
}
